Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(158)

Unified Diff: content/public/common/screen_info.h

Issue 2954793002: color: Replace more instances of ICCProfile with ColorSpace (Closed)
Patch Set: Created 3 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/common/view_messages.h ('k') | content/public/common/screen_info.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/public/common/screen_info.h
diff --git a/content/public/common/screen_info.h b/content/public/common/screen_info.h
index b758fed561b4c0562967ab437ab7a3655ebe1f3f..0a2afbb0e3205615680f759400f6b7a2bd8e69d4 100644
--- a/content/public/common/screen_info.h
+++ b/content/public/common/screen_info.h
@@ -7,8 +7,8 @@
#include "content/common/content_export.h"
#include "content/public/common/screen_orientation_values.h"
+#include "ui/gfx/color_space.h"
#include "ui/gfx/geometry/rect.h"
-#include "ui/gfx/icc_profile.h"
namespace content {
@@ -23,8 +23,8 @@ struct CONTENT_EXPORT ScreenInfo {
// pixels.
float device_scale_factor = 1.f;
- // The ICC profile of the output display.
- gfx::ICCProfile icc_profile;
+ // The color space of the output display.
+ gfx::ColorSpace color_space = gfx::ColorSpace::CreateSRGB();
// The screen depth in bits per pixel
uint32_t depth = 0;
« no previous file with comments | « content/common/view_messages.h ('k') | content/public/common/screen_info.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698